@@ -25,7 +25,7 @@
 #include "k9dvdprogress.h"
 #include "k9ifo2.h"
 #include <tqapplication.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 #include <sys/stat.h>
@@ -1042,7 +1042,7 @@ TQString &k9DVD::getFormat() {
 }
 
 int k9DVD::getVampsID(int type) {
-    int abase;
+    int abase = 0;
     if (type >= 0x80 && type <= 0x87) {
         // AC3 audio
         abase = 0x80;
