@@ -17,10 +17,10 @@
 /**
 	@author Jean-Michel PETIT <k9copy@free.fr>
 */
-class k9Process : public KProcess
+class k9Process : public TDEProcess
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
     k9Process(TQObject *parent = 0, const char *name = 0);
     void sync();
@@ -33,7 +33,7 @@ private:
     TQString m_debug;
     TQTime m_elapsed;
 private slots:
-   void slotProcessExited(KProcess *proc);
+   void slotProcessExited(TDEProcess *proc);
 };
 
 #endif
