@@ -33,7 +33,7 @@
 #include "k9updatefactor.h"
 #include "k9haldevice.h"
 #include "k9titleencopt.h"
-#include <kselect.h>
+#include <tdeselect.h>
 #include <kcombobox.h>
 #include <tqtextbrowser.h>
 #include <tqapplication.h>
@@ -53,12 +53,12 @@
 #include <tqspinbox.h>
 #include <tqpainter.h>
 #include <kdirselectdialog.h>
-#include <kio/global.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
+#include <tdeio/global.h>
+#include <tdeio/job.h>
+#include <tdeio/netaccess.h>
 #include <kdiskfreesp.h>
 #include <tqvaluelist.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <tqbitmap.h>
 
 
@@ -109,13 +109,13 @@ k9Main::k9Main(TQWidget* parent, const char* name, k9CdDrives *_drives)
 
   items.setAutoDelete(true);
   listView1->setDefaultRenameAction(TQListView::Accept);
-  //    KStandardDirs kd;
+  //    TDEStandardDirs kd;
   m_prefOutput=locateLocal("tmp","k9copy/",true); //kd.findResource("tmp","");
   connect(drives,TQT_SIGNAL(deviceAdded( k9CdDrive*)),this,TQT_SLOT(deviceAdded( k9CdDrive* )));
   connect(drives,TQT_SIGNAL(deviceRemoved( k9CdDrive*)),this,TQT_SLOT(deviceRemoved( k9CdDrive* )));
 
   readSettings();
-  bInputOpen->setPixmap(SmallIcon("fileopen"));
+  bInputOpen->setPixmap(SmallIcon("document-open"));
   bInputOpenDir->setPixmap(SmallIcon("folder_open"));
   emit SelectionChanged(NULL,true);
   m_update=new k9UpdateFactor(TQT_TQOBJECT(this),"");
@@ -499,19 +499,19 @@ TQString  k9Main::getDevice(TQComboBox *_combo)
   if ((index==-1) || (_combo->currentText() ==i18n("ISO Image")))
   {
     res=_combo->currentText();
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 
     KURL url=KURL::fromPathOrURL(res);
-    //KIO::mount(true,0,res,"",true);
-    KIO::UDSEntry entry;
+    //TDEIO::mount(true,0,res,"",true);
+    TDEIO::UDSEntry entry;
     //first call to mount the device
-    KIO::NetAccess::stat(KURL::fromPathOrURL(res+"/."),entry,0);
-    if (KIO::NetAccess::stat(url,entry,0) )
+    TDEIO::NetAccess::stat(KURL::fromPathOrURL(res+"/."),entry,0);
+    if (TDEIO::NetAccess::stat(url,entry,0) )
     {
-      KIO::UDSEntry::iterator it;
+      TDEIO::UDSEntry::iterator it;
       for ( it = entry.begin(); it != entry.end(); ++it )
       {
-        if ( (*it).m_uds== KIO::UDS_LOCAL_PATH) {
+        if ( (*it).m_uds== TDEIO::UDS_LOCAL_PATH) {
           res=(*it).m_str; 
         }
       }
@@ -576,7 +576,7 @@ void k9Main::Open()
   root->setRenameEnabled(0,true);
   root->obj=NULL;
   root->streamType=NONE;
-  root->setPixmap(0,SmallIcon("dvd_unmount"));
+  root->setPixmap(0,SmallIcon("media-optical-dvd"));
 
   for (i=0;i<dvd->gettitlesetCount();i++)
   {
@@ -1440,7 +1440,7 @@ long k9Main::getFreeSpace(const TQString & _path)
 
   connect(FreeSp,TQT_SIGNAL(foundMountPoint (const TQString &, unsigned long , unsigned long , unsigned long )),this,TQT_SLOT(foundMountPoint (const TQString &, unsigned long , unsigned long , unsigned long )));
   connect(FreeSp,TQT_SIGNAL(done ( )),this,TQT_SLOT(fspDone ()));
-  TQString mountPoint = KIO::findPathMountPoint( _path );
+  TQString mountPoint = TDEIO::findPathMountPoint( _path );
   FreeSp->readDF(mountPoint);
   do
   {
@@ -1474,7 +1474,7 @@ void k9Main::setOutput(TQString _output)
   {
     k9CdDrive * drive=(k9CdDrive*)recorderList.at(i);
     TQString c(drive->device);
-    //        qDebug ("output=" +c);
+    //        tqDebug ("output=" +c);
     if (c==_output)
     {
       cbOutputDev->setCurrentItem(i+2);
